==> ejc-sale-api-3.0.0-20221009.090207-230-sources.jar: com.ejianc.business.sale/salesorder/vo/DynamicVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

public class DynamicVO{
    private static final long serialVersionUID = 1L;

    private Long id;
    private Integer mid; // 子表主键
    private String parameter; // 参数名
    private String symbol; // 通配符
    private Integer sortcode; // 排序
    private String sqlvalue; // 下拉查询sql
    private Integer columntype; // 0-单选,1-多选，2-下拉，3-日期
    private Integer numericaltype; // 数值类型：0-数字，1-文本
    private String values; //

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getMid() {
        return mid;
    }

    public void setMid(Integer mid) {
        this.mid = mid;
    }

    public String getParameter() {
        return parameter;
    }

    public void setParameter(String parameter) {
        this.parameter = parameter;
    }

    public String getSymbol() {
        return symbol;
    }

    public void setSymbol(String symbol) {
        this.symbol = symbol;
    }

    public Integer getSortcode() {
        return sortcode;
    }

    public void setSortcode(Integer sortcode) {
        this.sortcode = sortcode;
    }

    public String getSqlvalue() {
        return sqlvalue;
    }

    public void setSqlvalue(String sqlvalue) {
        this.sqlvalue = sqlvalue;
    }

    public Integer getColumntype() {
        return columntype;
    }

    public void setColumntype(Integer columntype) {
        this.columntype = columntype;
    }

    public Integer getNumericaltype() {
        return numericaltype;
    }

    public void setNumericaltype(Integer numericaltype) {
        this.numericaltype = numericaltype;
    }

    public String getValues() {
        return values;
    }

    public void setValues(String values) {
        this.values = values;
    }
}

==> ejc-sale-api-3.0.0-20221010.021257-231-sources.jar: com.ejianc.business.sale/salesorder/vo/DynamicVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

public class DynamicVO{
    private static final long serialVersionUID = 1L;

//    private Long id;
//    private Integer mid; // 子表主键
    private String parameter; // 参数名
    private String symbol; // 通配符
    private Integer sortcode; // 排序
//    private String sqlvalue; // 下拉查询sql
    private Integer columntype; // 0-单选,1-多选，2-下拉，3-日期
    private Integer numericaltype; // 数值类型：0-数字，1-文本
    private JSONArray values; //

//    public Long getId() {
//        return id;
//    }
//
//    public void setId(Long id) {
//        this.id = id;
//    }
//
//    public Integer getMid() {
//        return mid;
//    }
//
//    public void setMid(Integer mid) {
//        this.mid = mid;
//    }

    public String getParameter() {
        return parameter;
    }

    public void setParameter(String parameter) {
        this.parameter = parameter;
    }

    public String getSymbol() {
        return symbol;
    }

    public void setSymbol(String symbol) {
        this.symbol = symbol;
    }

    public Integer getSortcode() {
        return sortcode;
    }

    public void setSortcode(Integer sortcode) {
        this.sortcode = sortcode;
    }

//    public String getSqlvalue() {
//        return sqlvalue;
//    }
//
//    public void setSqlvalue(String sqlvalue) {
//        this.sqlvalue = sqlvalue;
//    }

    public Integer getColumntype() {
        return columntype;
    }

    public void setColumntype(Integer columntype) {
        this.columntype = columntype;
    }

    public Integer getNumericaltype() {
        return numericaltype;
    }

    public void setNumericaltype(Integer numericaltype) {
        this.numericaltype = numericaltype;
    }

    public JSONArray getValues() {
        return values;
    }

    public void setValues(JSONArray values) {
        this.values = values;
    }
}
